@@ -12,6 +12,7 @@ from fast_tracker.trace import tags
 from fast_tracker.trace.carrier import Carrier
 from fast_tracker.trace.context import get_context
 from fast_tracker.trace.tags import Tag
+from fast_tracker.utils import functions
 from fast_tracker.utils.reader_type import ReaderType
 
 
@@ -101,6 +102,8 @@ def _gen_fast_get_response_func(old_execute):
                 set_code(config.tenant_code_reader, request, "tenant_code")
                 set_code(config.user_code_reader, request, "user_code")
                 set_code(config.env_code_reader, request, "env_code")
+
+                functions.log("tornado span is: %r", span)
             return result
 
     return _fast_get_response
